ChatBuilder class

Used as a Builder class for FlyChat

@property apiKey for the SDK @property enableMobileNumberLogin to enable login via mobile number @property isTrialLicenceKey to provide trial/live register and contact sync @property domainBaseUrl provides the base url for making api calls @property storageFolderName provides the Local Storage Folder Name @property iOSContainerID provides the App Group of the iOS Project

  • @property licenseKey provides the License Key @property groupConfig provides the data required for group implementation
Available extensions

Constructors

ChatBuilder({required String domainBaseUrl, String? storageFolderName, required String iOSContainerID, required String licenseKey, bool enableMobileNumberLogin = false, bool isTrialLicenceKey = true, bool enableDebugLog = false})

Properties

domainBaseUrl ↔ String
getter/setter pair
enableDebugLog ↔ bool
getter/setter pair
enableMobileNumberLogin ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iOSContainerID ↔ String
getter/setter pair
isTrialLicenceKey ↔ bool
getter/setter pair
licenseKey ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageFolderName ↔ String?
getter/setter pair

Methods

build() → Map

Available on ChatBuilder, provided by the BuilderParsing extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited