ContactChatMessage class

Constructors

ContactChatMessage({required String contactName, required List<String> contactPhoneNumbers, required List<bool> isChatAppUser, required String messageId})
ContactChatMessage.fromJson(Map<String, dynamic> json)
factory

Properties

contactName ↔ String
getter/setter pair
contactPhoneNumbers ↔ List<String>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isChatAppUser ↔ List<bool>
getter/setter pair
messageId ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited