MessageDeliveredStatus class

Constructors

MessageDeliveredStatus({String? deliveredCount, int? totalParticipatCount, required List<DeliveredParticipantList> participantList})
MessageDeliveredStatus.fromJson(Map<String, dynamic> json, String type)
factory

Properties

deliveredCount ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
participantList ↔ List<DeliveredParticipantList>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalParticipatCount ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited