MessageObject class

Constructors

MessageObject({required String toJid, required String messageType, String? textMessage, String? replyMessageId, double? latitude, double? longitude, String? contactName, List<String>? contactNumbers, String? file, String? fileName, String? caption, String? base64Thumbnail, String? audioDuration, bool? isAudioRecorded})

Properties

audioDuration ↔ String?
getter/setter pair
base64Thumbnail ↔ String?
getter/setter pair
caption ↔ String?
getter/setter pair
contactName ↔ String?
getter/setter pair
contactNumbers ↔ List<String>?
getter/setter pair
file ↔ String?
getter/setter pair
fileName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAudioRecorded ↔ bool?
getter/setter pair
latitude ↔ double?
getter/setter pair
longitude ↔ double?
getter/setter pair
messageType ↔ String
getter/setter pair
replyMessageId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textMessage ↔ String?
getter/setter pair
toJid ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited