ProfileData class

Constructors

ProfileData({String? email, String? image, bool? isAdminBlocked, bool? isBlocked, bool? isBlockedMe, bool? isGroupAdmin, bool? isGroupInOfflineMode, bool? isGroupProfile, bool? isItSavedContact, bool? isMuted, bool? isSelected, String? jid, String? mobileNumber, String? name, String? nickName, String? status})
ProfileData.fromJson(Map<String, dynamic> json)
factory

Properties

email ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ String?
getter/setter pair
isAdminBlocked ↔ bool?
getter/setter pair
isBlocked ↔ bool?
getter/setter pair
isBlockedMe ↔ bool?
getter/setter pair
isGroupAdmin ↔ bool?
getter/setter pair
isGroupInOfflineMode ↔ bool?
getter/setter pair
isGroupProfile ↔ bool?
getter/setter pair
isItSavedContact ↔ bool?
getter/setter pair
isMuted ↔ bool?
getter/setter pair
isSelected ↔ bool?
getter/setter pair
jid ↔ String?
getter/setter pair
mobileNumber ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
nickName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited