RecentChatData class

Constructors

RecentChatData({String? contactType, bool? isAdminBlocked, bool? isBlocked, bool? isBlockedMe, bool? isBroadCast, bool? isChatArchived, bool? isChatPinned, bool? isConversationUnRead, bool? isGroup, bool? isGroupInOfflineMode, bool? isItSavedContact, bool? isLastMessageRecalledByUser, bool? isLastMessageSentByMe, bool? isMuted, bool? isSelected, String? jid, String? lastMessageContent, String? lastMessageId, String? lastMessageStatus, dynamic lastMessageTime, String? lastMessageType, String? nickName, String? profileImage, String? profileName, dynamic unreadMessageCount})
RecentChatData.fromJson(Map<String, dynamic> json)
factory

Properties

contactType ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAdminBlocked ↔ bool?
getter/setter pair
isBlocked ↔ bool?
getter/setter pair
isBlockedMe ↔ bool?
getter/setter pair
isBroadCast ↔ bool?
getter/setter pair
isChatArchived ↔ bool?
getter/setter pair
isChatPinned ↔ bool?
getter/setter pair
isConversationUnRead ↔ bool?
getter/setter pair
isGroup ↔ bool?
getter/setter pair
isGroupInOfflineMode ↔ bool?
getter/setter pair
isItSavedContact ↔ bool?
getter/setter pair
isLastMessageRecalledByUser ↔ bool?
getter/setter pair
isLastMessageSentByMe ↔ bool?
getter/setter pair
isMuted ↔ bool?
getter/setter pair
isSelected ↔ bool?
getter/setter pair
jid ↔ String?
getter/setter pair
lastMessageContent ↔ String?
getter/setter pair
lastMessageId ↔ String?
getter/setter pair
lastMessageStatus ↔ String?
getter/setter pair
lastMessageTime ↔ dynamic
getter/setter pair
lastMessageType ↔ String?
getter/setter pair
nickName ↔ String?
getter/setter pair
profileImage ↔ String?
getter/setter pair
profileName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreadMessageCount ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited