RecentSearch class

Constructors

RecentSearch({required String? jid, required String? mid, required String? searchType, required String? chatType, required bool? isSearch})
RecentSearch.fromJson(Map<String, dynamic> json)
factory

Properties

chatType ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isSearch ↔ bool?
getter/setter pair
jid ↔ String?
getter/setter pair
mid ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchType ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited