Data class

Constructors

Data({String? token, String? username, String? password, bool? isExisting, bool? isProfileUpdated, RegConfig? config})
Data.fromJson(Map<String, dynamic> json)
factory

Properties

config ↔ RegConfig?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isExisting ↔ bool?
getter/setter pair
isProfileUpdated ↔ bool?
getter/setter pair
password ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String?
getter/setter pair
username ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited