RegisterModel class

Constructors

RegisterModel({Data? data, bool? isNewUser, String? message})
RegisterModel.fromJson(Map<String, dynamic> json)
factory

Properties

data ↔ Data?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isNewUser ↔ bool?
getter/setter pair
message ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited